@@ -1,7 +1,12 @@
 # -*- coding: utf-8 -*-
 import os
 import unittest
-import zlib
+import string
+import random
+try:
+	import zlib as binascii
+except ImportError:
+	import binascii
 import urllib
 import tempfile
 import shutil
@@ -11,10 +16,15 @@ from qiniu.auth import up
 from qiniu import resumable_io
 from qiniu import rs
 
-bucket = os.getenv("QINIU_BUCKET_NAME")
+bucket = os.getenv("QINIU_TEST_BUCKET")
 conf.ACCESS_KEY = os.getenv("QINIU_ACCESS_KEY")
 conf.SECRET_KEY = os.getenv("QINIU_SECRET_KEY")
 
+
+def r(length):
+	lib = string.ascii_uppercase
+	return ''.join([random.choice(lib) for i in range(0, length)])
+
 class TestBlock(unittest.TestCase):
 	def test_block(self):
 		policy = rs.PutPolicy(bucket)
@@ -25,7 +35,7 @@ class TestBlock(unittest.TestCase):
 		data_slice_2 = "\nbye!"
 		ret, err = resumable_io.mkblock(client, len(data_slice_2), data_slice_2)
 		assert err is None, err 
-		self.assertEqual(ret["crc32"], zlib.crc32(data_slice_2))
+		self.assertEqual(ret["crc32"], binascii.crc32(data_slice_2))
 
 		extra = resumable_io.PutExtra(bucket)
 		extra.mimetype = "text/plain"
@@ -34,7 +44,7 @@ class TestBlock(unittest.TestCase):
 		for i in xrange(0, len(extra.progresses)):
 			lens += extra.progresses[i]["offset"]
 
-		key = "sdk_py_resumable_block_4"
+		key = u"sdk_py_resumable_block_4_%s" % r(9)
 		ret, err = resumable_io.mkfile(client, key, lens, extra)
 		assert err is None, err
 		self.assertEqual(ret["hash"], "FtCFo0mQugW98uaPYgr54Vb1QsO0", "hash not match")
@@ -49,7 +59,7 @@ class TestBlock(unittest.TestCase):
 		policy = rs.PutPolicy(bucket)
 		extra = resumable_io.PutExtra(bucket)
 		extra.bucket = bucket
-		key = "sdk_py_resumable_block_5"
+		key = "sdk_py_resumable_block_5_%s" % r(9)
 		localfile = dst.name
 		ret, err = resumable_io.put_file(policy.token(), key, localfile, extra)
 		dst.close()
